@@ -27,3 +27,18 @@ class ValidationStepSchema(Schema):
     path_suffix = fields.String()
     processor = fields.Nested(ProcessorSchema, many=False)
     validators = fields.Nested(ValidatorSchema, many=True)
+
+
+class ValidationResultSchema(Schema):
+
+    """Serialized validation result"""
+
+    filepath = fields.String()
+    results = fields.List(
+        fields.Tuple(
+            (
+                fields.Raw(),
+                fields.Bool(),
+            )
+        )
+    )
