@@ -152,34 +152,3 @@ def meets_lick_threshold(
     """
     licks = value["items"]["behavior"]["lick_sensors"][0]["lick_events"]
     return len(licks), len(licks) >= threshold
-
-
-def meets_vsync_rate_threshold(
-    value: Dataset,
-    threshold: int,
-    tolerance: int,
-    line_label: str,
-) -> Tuple[float, bool]:
-    vsyncs_rising, vsyncs_falling = get_sync_line_data(value, line_label)
-    vsync_rate = 1 / np.median(np.diff(vsyncs_falling))
-    return vsync_rate, (threshold - tolerance) < vsync_rate < (threshold + tolerance)
-
-
-def meets_barcode_threshold(
-    value: Dataset,
-    threshold: int,
-    line_label: str,
-):
-    r, f = get_sync_line_data(value, line_label)
-    return len(f), len(f) >= threshold
-
-
-def meets_cam_sync_threshold(
-    value: Dataset,
-    threshold: int,
-    tolerance: int,
-    line_label: str,
-):
-    r, f = get_sync_line_data(value, line_label)
-    cam_rate = 1 / np.median(np.diff(f))
-    return cam_rate, (threshold - tolerance) < cam_rate < (threshold + tolerance)
